@@ -2,10 +2,12 @@ package cli
 
 import (
 	"fmt"
-	"runtime"
+	stdruntime "runtime"
+	"slices"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/engine"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/config"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
 	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 	"github.com/spf13/cobra"
 )
@@ -19,23 +21,34 @@ var upgradeCmd = &cobra.Command{
 	Long:  "Upgrade when a new version is available.",
 	Args:  cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		if runtime.GOOS == platform.LINUX {
+		supportedPlatforms := []string{
+			runtime.WINDOWS,
+			runtime.DARWIN,
+			runtime.LINUX,
+		}
+
+		if !slices.Contains(supportedPlatforms, stdruntime.GOOS) {
 			fmt.Print("\n⚠️ upgrade is not supported on this platform\n\n")
 			return
 		}
 
-		env := &platform.Shell{
-			CmdFlags: &platform.Flags{},
+		env := &runtime.Terminal{
+			CmdFlags: &runtime.Flags{},
 		}
 		env.Init()
 		defer env.Close()
 
+		terminal.Init(env.Shell())
+		fmt.Print(terminal.StartProgress())
+
+		defer fmt.Print(terminal.StopProgress())
+
 		if force {
 			upgrade.Run(env)
 			return
 		}
 
-		cfg := engine.LoadConfig(env)
+		cfg := config.Load(env)
 
 		if _, hasNotice := upgrade.Notice(env, true); !hasNotice {
 			if !cfg.DisableNotice {
