@@ -4,9 +4,9 @@ import (
 	"errors"
 	"fmt"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
@@ -61,7 +61,7 @@ func (c *cmd) parse(versionInfo string) (*version, error) {
 
 type language struct {
 	props              properties.Properties
-	env                platform.Environment
+	env                runtime.Environment
 	extensions         []string
 	folders            []string
 	commands           []*cmd
@@ -72,6 +72,9 @@ type language struct {
 	matchesVersionFile matchesVersionFile
 	homeEnabled        bool
 	displayMode        string
+	// root is the root folder of the project
+	projectFiles []string
+	projectRoot  *runtime.FileInfo
 
 	version
 	Error    string
@@ -97,6 +100,8 @@ const (
 	LanguageExtensions properties.Property = "extensions"
 	// LanguageFolders the list of folders to validate
 	LanguageFolders properties.Property = "folders"
+	// CacheVersion allows caching the version number
+	CacheVersion properties.Property = "cache_version"
 )
 
 func (l *language) Enabled() bool {
@@ -106,11 +111,19 @@ func (l *language) Enabled() bool {
 	inHomeDir := func() bool {
 		return l.env.Pwd() == l.env.Home()
 	}
+
 	var enabled bool
+
 	homeEnabled := l.props.GetBool(HomeEnabled, l.homeEnabled)
 	if inHomeDir() && !homeEnabled {
-		enabled = false
-	} else {
+		return false
+	}
+
+	if len(l.projectFiles) != 0 && l.hasProjectFiles() {
+		enabled = true
+	}
+
+	if !enabled {
 		// set default mode when not set
 		if len(l.displayMode) == 0 {
 			l.displayMode = l.props.GetString(DisplayMode, DisplayModeFiles)
@@ -126,7 +139,7 @@ func (l *language) Enabled() bool {
 		case DisplayModeContext:
 			fallthrough
 		default:
-			enabled = l.hasLanguageFiles() || l.hasLanguageFolders() || l.inLanguageContext()
+			enabled = l.hasLanguageFiles() || l.hasLanguageFolders() || l.inLanguageContext() || l.hasProjectFiles()
 		}
 	}
 
@@ -159,6 +172,16 @@ func (l *language) hasLanguageFiles() bool {
 	return false
 }
 
+func (l *language) hasProjectFiles() bool {
+	for _, extension := range l.projectFiles {
+		if configPath, err := l.env.HasParentFilePath(extension); err == nil {
+			l.projectRoot = configPath
+			return true
+		}
+	}
+	return false
+}
+
 func (l *language) hasLanguageFolders() bool {
 	for _, folder := range l.folders {
 		if l.env.HasFolder(folder) {
@@ -171,16 +194,31 @@ func (l *language) hasLanguageFolders() bool {
 // setVersion parses the version string returned by the command
 func (l *language) setVersion() error {
 	var lastError error
+	cacheVersion := l.props.GetBool(CacheVersion, false)
+
 	for _, command := range l.commands {
 		var versionStr string
 		var err error
+
+		versionKey := fmt.Sprintf("%s_version", command.executable)
+		versionURL := fmt.Sprintf("%s_version_url", command.executable)
+
+		if versionStr, OK := l.env.Cache().Get(versionKey); OK {
+			version, _ := command.parse(versionStr)
+			l.version = *version
+			l.version.Executable = command.executable
+			l.version.URL, _ = l.env.Cache().Get(versionURL)
+			return nil
+		}
+
 		if command.getVersion == nil {
 			if !l.env.HasCommand(command.executable) {
 				lastError = errors.New(noVersion)
 				continue
 			}
+
 			versionStr, err = l.env.RunCommand(command.executable, command.args...)
-			if exitErr, ok := err.(*platform.CommandError); ok {
+			if exitErr, ok := err.(*runtime.CommandError); ok {
 				l.exitCode = exitErr.ExitCode
 				lastError = fmt.Errorf("err executing %s with %s", command.executable, command.args)
 				continue
@@ -192,17 +230,27 @@ func (l *language) setVersion() error {
 				continue
 			}
 		}
+
 		version, err := command.parse(versionStr)
 		if err != nil {
 			lastError = fmt.Errorf("err parsing info from %s with %s", command.executable, versionStr)
 			continue
 		}
+
 		l.version = *version
 		if command.versionURLTemplate != "" {
 			l.versionURLTemplate = command.versionURLTemplate
 		}
+
 		l.buildVersionURL()
 		l.version.Executable = command.executable
+
+		if cacheVersion {
+			timeout := l.props.GetInt(properties.CacheTimeout, 1440)
+			l.env.Cache().Set(versionKey, versionStr, timeout)
+			l.env.Cache().Set(versionURL, l.version.URL, timeout)
+		}
+
 		return nil
 	}
 	if lastError != nil {
