@@ -6,14 +6,14 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Unity struct {
 	props properties.Properties
-	env   platform.Environment
+	env   runtime.Environment
 
 	UnityVersion  string
 	CSharpVersion string
@@ -39,16 +39,16 @@ func (u *Unity) Enabled() bool {
 	return true
 }
 
-func (u *Unity) GetUnityVersion() (version string, err error) {
+func (u *Unity) GetUnityVersion() (string, error) {
 	projectDir, err := u.env.HasParentFilePath("ProjectSettings")
 	if err != nil {
 		u.env.Debug("No ProjectSettings parent folder found")
-		return
+		return "", err
 	}
 
 	if !u.env.HasFilesInDir(projectDir.Path, "ProjectVersion.txt") {
 		u.env.Debug("No ProjectVersion.txt file found")
-		return
+		return "", err
 	}
 
 	versionFilePath := filepath.Join(projectDir.Path, "ProjectVersion.txt")
@@ -147,7 +147,7 @@ func (u *Unity) Template() string {
 	return " \ue721 {{ .UnityVersion }}{{ if .CSharpVersion }} {{ .CSharpVersion }}{{ end }} "
 }
 
-func (u *Unity) Init(props properties.Properties, env platform.Environment) {
+func (u *Unity) Init(props properties.Properties, env runtime.Environment) {
 	u.props = props
 	u.env = env
 }
