@@ -7,7 +7,7 @@ import (
 )
 
 func funcMap() template.FuncMap {
-	funcMap := map[string]interface{}{
+	funcMap := map[string]any{
 		"secondsRound": secondsRound,
 		"url":          url,
 		"path":         path,
@@ -16,6 +16,10 @@ func funcMap() template.FuncMap {
 		"replaceP":     replaceP,
 		"gt":           gt,
 		"lt":           lt,
+		"reason":       GetReasonFromStatus,
+		"hresult":      hresult,
+		"trunc":        trunc,
+		"readFile":     readFile,
 	}
 	for key, fun := range sprig.TxtFuncMap() {
 		if _, ok := funcMap[key]; !ok {
