@@ -1,18 +1,14 @@
 package upgrade
 
 import (
-	"context"
 	"fmt"
-	"io"
-	"net/http"
 	"os"
 
 	"github.com/charmbracelet/bubbles/spinner"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
 	"github.com/jandedobbeleer/oh-my-posh/src/build"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform/net"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 var (
@@ -98,6 +94,7 @@ func (m *model) View() string {
 
 	var message string
 	m.spinner.Spinner = spinner.Dot
+
 	switch m.state {
 	case validating:
 		message = "Validating current installation"
@@ -111,7 +108,7 @@ func (m *model) View() string {
 	return title + textStyle.Render(fmt.Sprintf("%s %s", m.spinner.View(), message))
 }
 
-func Run(env platform.Environment) {
+func Run(env runtime.Environment) {
 	titleStyle := lipgloss.NewStyle().Margin(1, 0, 1, 0)
 	title = "📦  Upgrading Oh My Posh"
 
@@ -128,23 +125,3 @@ func Run(env platform.Environment) {
 		os.Exit(1)
 	}
 }
-
-func downloadAsset(asset string) (io.ReadCloser, error) {
-	url := fmt.Sprintf("https://github.com/JanDeDobbeleer/oh-my-posh/releases/latest/download/%s", asset)
-
-	req, err := http.NewRequestWithContext(context.Background(), "GET", url, nil)
-	if err != nil {
-		return nil, err
-	}
-
-	resp, err := net.HTTPClient.Do(req)
-	if err != nil {
-		return nil, err
-	}
-
-	if resp.StatusCode != http.StatusOK {
-		return nil, fmt.Errorf("failed to download installer: %s", url)
-	}
-
-	return resp.Body, nil
-}
